@@ -1,11 +1,9 @@
 multinom = function(x, counts = FALSE){
   
   u = NULL
-  nu = -1
   
   if(!counts){
     u = as.vector(table(x))
-    nu = length(u)
   }else{
     ## make sure x is a vector of counts
     is.wholenumber = function(x, tol = .Machine$double.eps^0.5){abs(x - round(x)) < tol}
@@ -14,13 +12,10 @@ multinom = function(x, counts = FALSE){
       stop("if counts == TRUE then all elements of x must be integer and >= 0")
     
     u = x
-    nu = length(x)
   }
   
-  result = -1
+
+  r = .Call('multicool_multinomCoeff', PACKAGE = 'multicool', u)
   
-  r = .C("multinomCoeff", u = as.integer(u),
-          nu = as.integer(nu), result = as.integer(result))
-  
-  return(r$result)
+  return(r)
 }
\ No newline at end of file
